make_index_balanced_accuracy
============================================================================

.. currentmodule:: imbalanced_ensemble.metrics

.. autofunction:: make_index_balanced_accuracy

.. include:: ../../../back_references/imbalanced_ensemble.metrics.make_index_balanced_accuracy.examples

.. raw:: html

    <div style='clear:both'></div>